@@ -8,6 +8,9 @@ import requests
 import uuid
 import datetime
 
+import pkg_resources
+from pkg_resources import DistributionNotFound
+
 from types import ModuleType
 from .constants import URL, HTTP_STATUS_CODE, ERROR_CODE
 
@@ -55,6 +58,15 @@ class Client:
         for name, Klass in RESOURCE_CLASSES.items():
             setattr(self, name, Klass(self))
 
+    def get_version(self):
+        version = ""
+        try:
+            version = pkg_resources.require("paypayopa")[0].version
+        except DistributionNotFound:
+            print('DistributionNotFound')
+        return version
+
+
     def _set_base_url(self, **options):
         if self.production_mode is False:
             base_url = self.DEFAULTS['sandbox_base_url']
@@ -150,10 +162,9 @@ class Client:
                     msg = json_response['resultInfo']['message']
                 if 'code' in json_response['resultInfo']:
                     code = str(json_response['resultInfo']['code'])
+            # More error will be returned by API response
             if str.upper(code) == ERROR_CODE.SERVER_ERROR:
                 raise ServerError(msg)
-            else:
-                raise ServerError(msg)
 
     def get(self, path, params, **options):
         """
